* Output options: all can be turned on/off by adding or removing the 'NO':
  page number, date, centering, or page breaks, page length and width;
OPTIONS nonumber nodate nocenter formdlim='-' pagesize=MAX linesize=MAX;
* Eliminate SAS default names of tables in output (TRACE ON to show);
TITLE; ODS TRACE OFF;

* Location for DATA -- change this to be your directory;
%LET filesave=   F:\Example Data\Chapter 789 Data\WP Fluctuation;
LIBNAME filesave "&filesave.";

**************************************************************************************
********				Unconditional Models for Symptoms 	 				   *******
**************************************************************************************;

* Import data to work library;
DATA chapter7_fluctuation; SET filesave.chapter7_fluctuation; RUN;

* WP Fluctuation example from chapter 7 -- preliminary models;

TITLE1 "Empty Model for Symptoms -- REML";
PROC MIXED DATA=chapter7_fluctuation COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOPROFILE METHOD=REML;
	CLASS ID;
	MODEL symptom5 = / SOLUTION DDFM=SATTERTHWAITE NOTEST;
	RANDOM INTERCEPT / VCORR TYPE=UN SUBJECT=ID;
	REPEATED / TYPE=VC SUBJECT=ID;
RUN; TITLE1;
TITLE1 "Empty Model for Symptoms --ML";
PROC MIXED DATA=chapter7_fluctuation COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOPROFILE METHOD=ML;
	CLASS ID;
	MODEL symptom5 = / SOLUTION DDFM=SATTERTHWAITE NOTEST;
	RANDOM INTERCEPT / VCORR TYPE=UN SUBJECT=ID;
	REPEATED / TYPE=VC SUBJECT=ID;
RUN; TITLE1;
TITLE1 "Saturated Means by Day in Study, Random Intercept Variance Model";
PROC MIXED DATA=chapter7_fluctuation COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOPROFILE METHOD=ML;
	CLASS ID studyday;
	MODEL symptom5 = studyday / SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT / VCORR TYPE=UN SUBJECT=ID;
	REPEATED / TYPE=VC SUBJECT=ID;
	LSMEANS studyday / DIFF=ALL;
RUN; TITLE1;
TITLE1 "Fixed Linear Day of Study, Random Intercept Variance Model";
PROC MIXED DATA=chapter7_fluctuation COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOPROFILE METHOD=ML;
	CLASS ID;
	MODEL symptom5 = studyday1 / SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT  / VCORR TYPE=UN SUBJECT=ID;
	REPEATED / R RCORR TYPE=VC SUBJECT=ID;
RUN; TITLE1;
TITLE1 "Random Linear Day of Study Model";
PROC MIXED DATA=chapter7_fluctuation COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOPROFILE METHOD=ML;
	CLASS ID;
	MODEL symptom5 = studyday1 / SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT studyday1 / VCORR TYPE=UN SUBJECT=ID;
	REPEATED / R RCORR TYPE=VC SUBJECT=ID;
RUN; TITLE1;

TITLE1 "Saturated Means by Day of Week, Random Intercept Variance Model";
PROC MIXED DATA=chapter7_fluctuation COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOPROFILE METHOD=ML;
	CLASS ID dayofweek;
	MODEL symptom5 = dayofweek / SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT / VCORR TYPE=UN SUBJECT=ID;
	REPEATED / TYPE=VC SUBJECT=ID;
	LSMEANS dayofweek / DIFF=ALL;
RUN; TITLE1;
TITLE1 "Fixed Weekend, Random Intercept Variance Model";
PROC MIXED DATA=chapter7_fluctuation COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOPROFILE METHOD=ML;
	CLASS ID;
	MODEL symptom5 = weekend / SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT  / VCORR TYPE=UN SUBJECT=ID;
	REPEATED / R RCORR TYPE=VC SUBJECT=ID;
RUN; TITLE1;
TITLE1 "Random Weekend Variance Model";
PROC MIXED DATA=chapter7_fluctuation COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOPROFILE METHOD=ML;
	CLASS ID;
	MODEL symptom5 = weekend / SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT weekend / VCORR TYPE=UN SUBJECT=ID;
	REPEATED / R RCORR TYPE=VC SUBJECT=ID;
RUN; TITLE1;

/*TITLE1 "Empty Means, Auto-Regressive Variance Model";
PROC MIXED DATA=chapter7_fluctuation COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOPROFILE METHOD=ML;
	CLASS ID;
	MODEL symptom5 =  / SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT / VCORR TYPE=UN SUBJECT=ID;
	REPEATED / TYPE=SP(POW)(studyday);* SUBJECT=ID;
RUN; TITLE1; * Won't work; */


**************************************************************************************
********	REPORTED Time-Invariant Predictor Models: Fluctuation Example  	   *******
**************************************************************************************;

TITLE1 "Eq 7.3: Empty Means, Random Intercept Model";
PROC MIXED DATA=chapter7_fluctuation COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOPROFILE METHOD=ML;
	CLASS ID;
	MODEL symptom5 =  / SOLUTION DDFM=SATTERTHWAITE NOTEST;
	RANDOM INTERCEPT / VCORR TYPE=UN SUBJECT=ID;
	REPEATED / TYPE=VC SUBJECT=ID;
RUN; TITLE1;

**************************************************************************************************;
/* To use Regions Macro, enter:
	FixData=	Name of dataset that stores fixed effects for model	(SolutionF on ODS)
	InvData=	Name of dataset that stores X'X inv matrix for model  (CovB on ODS)
	Pred=		Case-sensitive name of predictor effect regions are for 
	Mod=		Case-sensitive name of moderator effect (for region values)
	ModCenter=	Centering point of moderator predictor
	Interact=	Case-sensitive name of interaction effect 
	Order=		Order of entry of interaction in MODEL statement */

%MACRO Regions(FixData, InvData, Pred, Mod, ModCenter, Interact, Order);
DATA _NULL_; SET &FixData.; WHERE Effect="&Pred.";
	CALL SYMPUT('Bpred', Estimate); CALL SYMPUT('SEpred', StdErr); RUN;	
DATA _NULL_; SET &FixData.; WHERE Effect="&Interact.";
	CALL SYMPUT('Binter', Estimate); CALL SYMPUT('SEinter', StdErr); RUN; 
%LET order=%EVAL(&order.+1);
DATA _NULL_; SET &InvData.; WHERE INDEX(Effect,"&Interact.")>0;
	CALL SYMPUT('CovPredInt', Col&order.); RUN;	
%PUT Bpred=&Bpred. SEpred=&SEpred. Binter=&Binter. SEinter=&SEinter. CovPredInt=&CovPredInt.;
DATA Regions;  * Intermediate calculations;
	A=(1.96*1.96)*(&SEinter.*&SEinter.)-(&Binter.*&Binter.);
	B=2*((1.96*1.96)*&CovPredInt.-(&Bpred.*&Binter.));
	C=(1.96*1.96*&SEpred.*&SEpred.)-(&Bpred.*&Bpred.);
	CenteredLower=((-1*B)+SQRT((B*B)-4*A*C))/(2*A); CALL SYMPUT('cenlower',ROUND(CenteredLower,.001));
	CenteredUpper=((-1*B)-SQRT((B*B)-4*A*C))/(2*A); CALL SYMPUT('cenupper',ROUND(CenteredUpper,.001));
	UncenteredLower=CenteredLower+&ModCenter.; CALL SYMPUT('uncenlower',ROUND(UncenteredLower,.001));
	UncenteredUpper=CenteredUpper+&ModCenter.; CALL SYMPUT('uncenupper',ROUND(UncenteredUpper,.001));
RUN;
TITLE1 "The effect of &pred. will be significant at centered values of &mod. BELOW the lower bound"; 
TITLE2 "and ABOVE the upper bound, which translate to these uncentered lower and upper bounds.";  
PROC PRINT DATA=Regions NOOBS; VAR CenteredLower--UncenteredUpper; RUN; TITLE1;	TITLE2;
%MEND Regions;
***************************************************************************************************;

TITLE1 "Eq 7.4: Adding Sex and Age to Model for the Means";
PROC MIXED DATA=chapter7_fluctuation COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOPROFILE METHOD=ML;
	CLASS ID;
	MODEL symptom5 =  female age80 female*age80 / SOLUTION DDFM=SATTERTHWAITE COVB OUTPM=Predicted;
	RANDOM INTERCEPT / TYPE=UN SUBJECT=ID;
	REPEATED / TYPE=VC SUBJECT=ID;
	ESTIMATE "Age Slope for Men"   age80 1 female*age80 0;
	ESTIMATE "Age Slope for Women" age80 1 female*age80 1;
	ESTIMATE "Sex Diff at Age 79.56"  female 1 female*age80 -0.440;
	ESTIMATE "Sex Diff at Age 60.447" female 1 female*age80 -19.553;
* Save pieces of output for use in macros (optional);
    ODS OUTPUT CovB=work.Inv7_4 SolutionF=work.Fix7_4;
RUN; TITLE1;
PROC CORR DATA=Predicted; VAR pred symptom5; RUN;
* Call macro to calculate regions of significance for gender effect;
%Regions(FixData=work.Fix7_4, InvData=work.Inv7_4, Pred=female, Mod=age80, ModCenter=80, Interact=female*age80, Order=3);

*** HETEROGENEOUS VARIANCE MODELS;

TITLE1 "Eq 7.5: Adding Sex and Age Interaction to Predict Heterogeneity of Level-2 Variance";  * Doesn't help;
PROC NLMIXED DATA=chapter7_fluctuation METHOD=GAUSS TECH=NEWRAP GCONV=1e-12;  
	* Must define all parameters to be estimated and provide start values;
	* First line is fixed effects, second line is variances;
		PARMS fint=1.7 fsex=-.53 fage=.10 fsexage=-.11   
      	  	  vU0int=1 vU0sex=0 vU0age=0 vU0sexage=0
			  varEint=1;
	* Setting up level-2 equations;
				b0i = fint + fsex*female + fage*age80 + fsexage*female*age80 + U0i; 
	* Setting up level-1 equation WITHOUT level-1 residual;
				y = (b0i);
	* Model for heterogeneous variance at level-2;
   				vU0 = EXP(vU0int + vU0sex*female + vU0age*age80 + vU0sexage*female*age80);
				varE = EXP(varEint);
  	* Telling it which DV, defining level-1 residual;
	* symptom5 is normally distributed with a mean of "y" and a variance of "VarE";
		MODEL symptom5 ~ NORMAL(y,varE);  
	* Defining random effects: normally distributed with means and variances;
		RANDOM 	U0i ~ normal([0],[vU0]) SUBJECT=ID;
	* Requesting model-implied effects or quantities; 
		ESTIMATE "Age Slope for Women" fage+fsexage;
		ESTIMATE "Random Int Variance" EXP(vU0int);
		ESTIMATE "Residual Variance"   EXP(varEint);
		ESTIMATE "Age Effect on Random Int Var for Women" vU0age+vU0sexage;
RUN; TITLE1; 

TITLE1 "Eq 7.6: Add Random Scale Factor - blows up";  * Doesn't help;
PROC NLMIXED DATA=chapter7_fluctuation METHOD=GAUSS TECH=QUANEW MAXFUNC=5000 MAXITER=5000; *GCONV=1e-12;  
	* Must define all parameters to be estimated and provide start values;
	* First line is fixed effects, second line is variances;
		PARMS fint=1.7 fsex=-.53 fage=.10 fsexage=-.11   
      	  	  varEint=-.48 vU0int=.06 cU0scale=.006 vscale=.002;
	* Setting up level-2 equations;
				b0i = fint + fsex*female + fage*age80 + fsexage*female*age80 + U0i; 
	* Setting up level-1 equation WITHOUT level-1 residual;
				y = (b0i);
	* Model for heterogeneous variance at level-2 and level-1;
   				vU0 = EXP(vU0int);
				varE = EXP(varEint + Scalei);
  	* Telling it which DV, defining level-1 residual;
	* symptom5 is normally distributed with a mean of "y" and a variance of "VarE";
		MODEL symptom5 ~ NORMAL(y,varE);  
	* Defining random effects: normally distributed with means and variances;
		RANDOM 	U0i Scalei ~ normal([0,0],[vU0,cU0scale,vscale]) SUBJECT=ID; 
RUN; TITLE1;

TITLE1 "Eq 7.7: Adding Sex and Age Interaction to Predict Heterogeneity of Level-1 Variance";  * Doesn't help;
PROC NLMIXED DATA=chapter7_fluctuation METHOD=GAUSS TECH=NEWRAP GCONV=1e-12;  
	* Must define all parameters to be estimated and provide start values;
	* First line is fixed effects, second line is variances;
		PARMS fint=1.7 fsex=-.53 fage=.10 fsexage=-.11 vU0int=1   
      	  	  varEint=1 varEsex=0 varEage=0 varEsexage=0;
	* Setting up level-2 equations;
				b0i = fint + fsex*female + fage*age80 + fsexage*female*age80 + U0i; 
	* Setting up level-1 equation WITHOUT level-1 residual;
				y = (b0i);
	* Model for heterogeneous variance at level-2 and level-1;
   				vU0 = EXP(vU0int);
				varE = EXP(varEint + varEsex*female + varEage*age80 + varEsexage*female*age80);
  	* Telling it which DV, defining level-1 residual;
	* symptom5 is normally distributed with a mean of "y" and a variance of "VarE";
		MODEL symptom5 ~ NORMAL(y,varE);  
	* Defining random effects: normally distributed with means and variances;
		RANDOM 	U0i ~ normal([0],[vU0]) SUBJECT=ID;
	* Requesting model-implied effects or quantities; 
		ESTIMATE "Age Slope for Women" fage+fsexage;
		ESTIMATE "Random Int Variance" EXP(vU0int);
		ESTIMATE "Residual Variance"   EXP(varEint); 
		ESTIMATE "Age Effect on Residual Var for Women" varEage+varEsexage;
RUN; TITLE1; 


**************************************************************************************
********	REPORTED Time-Invariant Predictor Models: Change Example  	   	   *******
**************************************************************************************;

**** RISKY BEHAVIOR EXAMPLE;

* Location for DATA -- change this to be your directory;
%LET filesave=   F:\Example Data\Chapter 789 Data\WP Change;
LIBNAME filesave "&filesave.";

* Bringing in multivarate data into work library, stacking into longitudinal;
DATA chapter7_change_stacked; SET filesave.chapter7_change;
	occasion=1; age=age1; risky=risky1*10; OUTPUT;
	occasion=2; age=age2; risky=risky2*10; OUTPUT;
	occasion=3; age=age3; risky=risky3*10; OUTPUT;
	occasion=4; age=age4; risky=risky4*10; OUTPUT;
	occasion=5; age=age5; risky=risky5*10; OUTPUT;
	occasion=6; age=age6; risky=risky6*10; OUTPUT;
	occasion=7; age=age7; risky=risky7*10; OUTPUT;
LABEL	FamilyID= 	"FamilyID: Level-2 ID variable"
		Attitude1=	"Parent Attitudes at Occasion 1"
		occasion= 	"occasion: Occasion of Measurement"
		age=		"age: Exact Age"
		risky=		"risky: Risky Behavior";
RUN;

* Centering predictor variables in stacked data;
DATA chapter7_change_stacked; SET chapter7_change_stacked;
* Center time at age 18;
	age18 = age - 18; LABEL age18= "age18: Age (0=18)";
* Center time-invariant predictor at 4;
	Age12Att4 = Attitude1 - 4; LABEL Age12Att4= "Age12Att4: Mom Attitudes at Age 12 (0=4)";
RUN;

*** Examining individual growth trajectories;
* Setting generic plotting options for text, size, and joining lines;
GOPTIONS NOBORDER FTEXT=Triplex FTITLE=Triplex VSIZE=7in HSIZE=7in INTERPOL=JOIN
GSFNAME=outgraph DEV=BMP GSFMODE=replace; RUN;

* Plot for DV by age;
FILENAME outgraph "&filesave.\Risky Behavior across Age.bmp"; 
TITLE1 JUSTIFY=CENTER HEIGHT=1.5 "Risky Behavior across Age"; 
PROC GPLOT DATA=chapter7_change_stacked;
	 * Settings for Y-axis;
	 AXIS1 LABEL=(HEIGHT=1.5 ANGLE=90 "Risky Behavior") LENGTH=5.75in ORDER=(10 TO 50 BY 5);
	 * Settings for X-axis;
	 AXIS2 LABEL=(HEIGHT=1.5 "Age") LENGTH=6.0in ORDER=(12 TO 18 BY 1);
	 * Plot Y by X = person ID, use settings for axes defined above, kill legend;
	 PLOT risky*age=FamilyID / VAXIS=AXIS1 HAXIS=AXIS2 NOLEGEND;  
RUN; QUIT; TITLE1;

TITLE "Empty Means, Random Intercept Model for Risky Behavior";
PROC MIXED DATA=chapter7_change_stacked NOITPRINT NOCLPRINT COVTEST IC NAMELEN=100 METHOD=ML;
	CLASS FamilyID occasion;
	MODEL risky = / SOLUTION DDFM=Satterthwaite NOTEST;
	RANDOM INTERCEPT / VCORR TYPE=UN SUBJECT=FamilyID; RUN; TITLE;

TITLE "Saturated Means, Unstructured Variance Model for Risky Behavior";
PROC MIXED DATA=chapter7_change_stacked NOITPRINT NOCLPRINT COVTEST IC NAMELEN=100 METHOD=ML;
	CLASS FamilyID occasion;
	MODEL risky = occasion / SOLUTION DDFM=Satterthwaite;
	REPEATED occasion / R RCORR TYPE=UN SUBJECT=FamilyID; 
	LSMEANS occasion; RUN; TITLE;

TITLE1 "Age 18 = 0";
TITLE2 "Fixed Linear Age, Random Intercept Model for Risky Behavior";
PROC MIXED DATA=chapter7_change_stacked NOITPRINT NOCLPRINT COVTEST IC NAMELEN=100 METHOD=ML;
	CLASS FamilyID occasion;
	MODEL risky = age18 / SOLUTION DDFM=Satterthwaite NOTEST;
	RANDOM INTERCEPT / TYPE=UN SUBJECT=FamilyID;
	ESTIMATE "Intercept at Age 12" intercept 1 age18 -6;
RUN; TITLE2;

TITLE2 "Random Linear Age Model for Risky Behavior";
PROC MIXED DATA=chapter7_change_stacked NOITPRINT NOCLPRINT COVTEST IC NAMELEN=100 METHOD=ML;
	CLASS FamilyID occasion;
	MODEL risky = age18 / SOLUTION DDFM=Satterthwaite NOTEST;
	RANDOM INTERCEPT age18 / TYPE=UN SUBJECT=FamilyID; 
RUN; TITLE2;

TITLE2 "Fixed Quadratic, Random Linear Age Model for Risky Behavior";
PROC MIXED DATA=chapter7_change_stacked NOITPRINT NOCLPRINT COVTEST IC NAMELEN=100 METHOD=ML;
	CLASS FamilyID occasion;
	MODEL risky = age18 age18*age18 / SOLUTION DDFM=Satterthwaite NOTEST;
	RANDOM INTERCEPT age18 / TYPE=UN SUBJECT=FamilyID;
	REPEATED occasion / TYPE=VC SUBJECT=FamilyID; 
	ESTIMATE "Intercept at Age 12" 		intercept 1 age18 -6 age18*age18 36;
	ESTIMATE "Linear Slope at Age 12" 	age18 1 age18*age18 -12;
RUN; TITLE2;

TITLE "Random Quadratic Age Model for Risky Behavior";
PROC MIXED DATA=chapter7_change_stacked NOITPRINT NOCLPRINT COVTEST IC NAMELEN=100 METHOD=ML;
	CLASS FamilyID occasion;
	MODEL risky = age18 age18*age18 / SOLUTION DDFM=Satterthwaite NOTEST;
	RANDOM INTERCEPT age18 age18*age18 / TYPE=UN SUBJECT=FamilyID; 
RUN; TITLE2;

TITLE "Fixed Cubic, Random Linear Age Model for Risky Behavior";
PROC MIXED DATA=chapter7_change_stacked NOITPRINT NOCLPRINT COVTEST IC NAMELEN=100 METHOD=ML;
	CLASS FamilyID occasion;
	MODEL risky = age18 age18*age18 age18*age18*age18 / SOLUTION DDFM=Satterthwaite NOTEST;
	RANDOM INTERCEPT age18 / TYPE=UN SUBJECT=FamilyID; RUN; TITLE2;

****** ADD EFFECTS OF TIME-INVARIANT ATTITUDES;

TITLE1 "Age 18 = 0";
TITLE2 "Eq 7.8: Fixed Quadratic, Random Linear Age Model for Risky Behavior";
PROC MIXED DATA=chapter7_change_stacked NOITPRINT NOCLPRINT COVTEST IC NAMELEN=100 METHOD=ML;
	CLASS FamilyID occasion;
	MODEL risky = age18 age18*age18 / SOLUTION DDFM=Satterthwaite NOTEST OUTPM=PredAge;
	RANDOM INTERCEPT age18 / TYPE=UN SUBJECT=FamilyID; RUN;  
PROC CORR DATA=PredAge; VAR risky Pred; RUN;

TITLE3 "Fixed Effects of Parent Attitudes on Intercept";
PROC MIXED DATA=chapter7_change_stacked NOITPRINT NOCLPRINT COVTEST IC NAMELEN=100 METHOD=ML;
	CLASS FamilyID occasion;
	MODEL risky = age18 age18*age18 Age12Att4 
					/ SOLUTION DDFM=Satterthwaite NOTEST OUTPM=PredInt;
	RANDOM INTERCEPT age18 / TYPE=UN SUBJECT=FamilyID; RUN; 
PROC CORR DATA=PredInt; VAR risky Pred; RUN; TITLE3;

TITLE3 "Fixed Effects of Parent Attitudes on Intercept, Linear";
PROC MIXED DATA=chapter7_change_stacked NOITPRINT NOCLPRINT COVTEST IC NAMELEN=100 METHOD=ML;
	CLASS FamilyID occasion;
	MODEL risky = age18 age18*age18 Age12Att4 Age12Att4*age18 
					/ SOLUTION DDFM=Satterthwaite NOTEST OUTPM=PredLin;
	RANDOM INTERCEPT age18 / TYPE=UN SUBJECT=FamilyID; 
* Simple effects of attitudes;
	ESTIMATE "Attitude Effect at Age 12" Age12Att4 1 Age12Att4*age18 -6;
	ESTIMATE "Attitude Effect at Age 13" Age12Att4 1 Age12Att4*age18 -5;
	ESTIMATE "Attitude Effect at Age 14" Age12Att4 1 Age12Att4*age18 -4;
	ESTIMATE "Attitude Effect at Age 15" Age12Att4 1 Age12Att4*age18 -3;
	ESTIMATE "Attitude Effect at Age 16" Age12Att4 1 Age12Att4*age18 -2;
	ESTIMATE "Attitude Effect at Age 17" Age12Att4 1 Age12Att4*age18 -1;
	ESTIMATE "Attitude Effect at Age 18" Age12Att4 1 Age12Att4*age18  0;
* Simple effects of age;
	ESTIMATE "Linear Age Slope at Attitudes=1" age18 1 Age12Att4*age18  -3;
	ESTIMATE "Linear Age Slope at Attitudes=2" age18 1 Age12Att4*age18  -2;
	ESTIMATE "Linear Age Slope at Attitudes=3" age18 1 Age12Att4*age18  -1;
	ESTIMATE "Linear Age Slope at Attitudes=4" age18 1 Age12Att4*age18   0;
	ESTIMATE "Linear Age Slope at Attitudes=5" age18 1 Age12Att4*age18   1;
RUN; 
PROC CORR DATA=PredLin; VAR risky Pred; RUN; TITLE3;

TITLE3 "Eq 7.9: Fixed Effects of Parent Attitudes on Intercept, Linear, Quadratic";
PROC MIXED DATA=chapter7_change_stacked NOITPRINT NOCLPRINT COVTEST IC NAMELEN=100 METHOD=ML;
	CLASS FamilyID occasion;
	MODEL risky = age18 age18*age18 Age12Att4 Age12Att4*age18 Age12Att4*age18*age18 
					/ SOLUTION DDFM=Satterthwaite NOTEST OUTPM=PredQuad;
	RANDOM INTERCEPT age18 / TYPE=UN SUBJECT=FamilyID; RUN;
PROC CORR DATA=PredQuad; VAR risky Pred; RUN; TITLE3;
